@@ -1,7 +1,7 @@
 import logging
 from os import path
 from shutil import move
-from types import is_iterable
+from vtypes import is_iterable, get_error_message
 import tarfile
 import zipfile
 
